@@ -1,23 +1,23 @@
 # encoding: utf-8
 
-"""
-Common shape-related oxml objects
-"""
+"""Common shape-related oxml objects."""
 
-from __future__ import absolute_import
+from __future__ import (
+    absolute_import, division, print_function, unicode_literals
+)
 
-from ...enum.shapes import PP_PLACEHOLDER
-from ..ns import qn
-from ..simpletypes import (
+from pptx.enum.shapes import PP_PLACEHOLDER
+from pptx.oxml.ns import qn
+from pptx.oxml.simpletypes import (
     ST_Angle, ST_Coordinate, ST_Direction, ST_DrawingElementId, ST_LineWidth,
     ST_PlaceholderSize, ST_PositiveCoordinate, XsdBoolean, XsdString,
     XsdUnsignedInt
 )
-from ...util import Emu
-from ..xmlchemy import (
+from pptx.oxml.xmlchemy import (
     BaseOxmlElement, Choice, OptionalAttribute, OxmlElement,
     RequiredAttribute, ZeroOrOne, ZeroOrOneChoice
 )
+from pptx.util import Emu
 
 
 class BaseShapeElement(BaseOxmlElement):
@@ -218,17 +218,22 @@ class CT_ApplicationNonVisualDrawingProps(BaseOxmlElement):
 
 
 class CT_LineProperties(BaseOxmlElement):
-    """
-    Custom element class for <a:ln> element
-    """
-    eg_lineFillProperties = ZeroOrOneChoice(
-        (Choice('a:noFill'), Choice('a:solidFill'), Choice('a:gradFill'),
-         Choice('a:pattFill')),
-        successors=(
-            'a:prstDash', 'a:custDash', 'a:round', 'a:bevel', 'a:miter',
-            'a:headEnd', 'a:tailEnd', 'a:extLst'
-        )
+    """Custom element class for <a:ln> element"""
+    _tag_seq = (
+        'a:noFill', 'a:solidFill', 'a:gradFill', 'a:pattFill', 'a:prstDash',
+        'a:custDash', 'a:round', 'a:bevel', 'a:miter', 'a:headEnd',
+        'a:tailEnd', 'a:extLst'
     )
+    eg_lineFillProperties = ZeroOrOneChoice(
+        (
+            Choice('a:noFill'), Choice('a:solidFill'), Choice('a:gradFill'),
+            Choice('a:pattFill')
+        ),
+        successors=_tag_seq[4:]
+    )
+    prstDash = ZeroOrOne('a:prstDash', successors=_tag_seq[5:])
+    custDash = ZeroOrOne('a:custDash', successors=_tag_seq[6:])
+    del _tag_seq
     w = OptionalAttribute('w', ST_LineWidth, default=Emu(0))
 
     @property
@@ -238,6 +243,23 @@ class CT_LineProperties(BaseOxmlElement):
         """
         return self.eg_lineFillProperties
 
+    @property
+    def prstDash_val(self):
+        """Return value of `val` attribute of `a:prstDash` child.
+
+        Return |None| if not present.
+        """
+        prstDash = self.prstDash
+        if prstDash is None:
+            return None
+        return prstDash.val
+
+    @prstDash_val.setter
+    def prstDash_val(self, val):
+        self._remove_custDash()
+        prstDash = self.get_or_add_prstDash()
+        prstDash.val = val
+
 
 class CT_NonVisualDrawingProps(BaseOxmlElement):
     """
@@ -284,26 +306,32 @@ class CT_PositiveSize2D(BaseOxmlElement):
 
 
 class CT_ShapeProperties(BaseOxmlElement):
+    """Custom element class for `p:spPr` element.
+
+    Shared by ``<p:sp>``, ``<p:pic>``, and ``<p:cxnSp>`` elements as well as
+    a few more obscure ones.
     """
-    Custom element class for <p:spPr> element. Shared by ``<p:sp>``,
-    ``<p:pic>``, and ``<p:cxnSp>`` elements as well as a few more obscure
-    ones.
-    """
-    xfrm = ZeroOrOne('a:xfrm', successors=(
-        'a:custGeom', 'a:prstGeom', 'a:ln', 'a:effectLst', 'a:effectDag',
-        'a:scene3d', 'a:sp3d', 'a:extLst'
-    ))
-    eg_fillProperties = ZeroOrOneChoice(
-        (Choice('a:noFill'), Choice('a:solidFill'), Choice('a:gradFill'),
-         Choice('a:blipFill'), Choice('a:pattFill'), Choice('a:grpFill')),
-        successors=(
-            'a:ln', 'a:effectLst', 'a:effectDag', 'a:scene3d', 'a:sp3d',
-            'a:extLst'
-        )
+
+    _tag_seq = (
+        'a:xfrm', 'a:custGeom', 'a:prstGeom', 'a:noFill', 'a:solidFill',
+        'a:gradFill', 'a:blipFill', 'a:pattFill', 'a:grpFill', 'a:ln',
+        'a:effectLst', 'a:effectDag', 'a:scene3d', 'a:sp3d', 'a:extLst',
     )
-    ln = ZeroOrOne('a:ln', successors=(
-        'a:effectLst', 'a:effectDag', 'a:scene3d', 'a:sp3d', 'a:extLst'
-    ))
+    xfrm = ZeroOrOne('a:xfrm', successors=_tag_seq[1:])
+    eg_fillProperties = ZeroOrOneChoice(
+        (
+            Choice('a:noFill'), Choice('a:solidFill'), Choice('a:gradFill'),
+            Choice('a:blipFill'), Choice('a:pattFill'), Choice('a:grpFill')
+        ),
+        successors=_tag_seq[9:]
+    )
+    ln = ZeroOrOne('a:ln', successors=_tag_seq[10:])
+    del _tag_seq
+
+    @property
+    def custGeom(self):
+        """The `a:custGeom` child element, or None if not present."""
+        return self.find(qn('a:custGeom'))
 
     @property
     def cx(self):
